R/DBI.R
dbSendStatement-DatabaseConnectorConnection-character-method.RdThe dbSendStatement() method only submits and synchronously executes the
SQL data manipulation statement (e.g., UPDATE, DELETE,
INSERT INTO, DROP TABLE, ...) to the database engine. To query
the number of affected rows, call dbGetRowsAffected() on the
returned result object. You must also call dbClearResult() after
that. For interactive use, you should almost always prefer
dbExecute().
# S4 method for class 'DatabaseConnectorConnection,character'
dbSendStatement(conn, statement, ...)A DBI::DBIConnection object,
as returned by dbConnect().
a character string containing SQL.
Other parameters passed on to methods.
dbSendStatement() returns
an S4 object that inherits from DBI::DBIResult.
The result set can be used with DBI::dbGetRowsAffected() to
determine the number of rows affected by the query.
Once you have finished using a result, make sure to clear it
with DBI::dbClearResult().
dbSendStatement() comes with a default implementation that simply
forwards to dbSendQuery(), to support backends that only
implement the latter.
For queries: dbSendQuery() and dbGetQuery().
Other DBIConnection generics:
DBIConnection-class,
dbAppendTable(),
dbAppendTableArrow(),
dbCreateTable(),
dbCreateTableArrow(),
dbDataType(),
dbDisconnect(),
dbExecute(),
dbExistsTable(),
dbGetException(),
dbGetInfo(),
dbGetQuery(),
dbGetQueryArrow(),
dbIsReadOnly(),
dbIsValid(),
dbListFields(),
dbListObjects(),
dbListResults(),
dbListTables(),
dbQuoteIdentifier(),
dbReadTable(),
dbReadTableArrow(),
dbRemoveTable(),
dbSendQuery(),
dbSendQueryArrow(),
dbUnquoteIdentifier(),
dbWriteTable(),
dbWriteTableArrow()
Other command execution generics:
dbBind(),
dbClearResult(),
dbExecute(),
dbGetRowsAffected()