This method returns the number of rows that were added, deleted, or updated by a data manipulation statement.
# S4 method for class 'DatabaseConnectorJdbcResult'
dbGetRowsAffected(res, ...)An object inheriting from DBI::DBIResult.
Other arguments passed on to methods.
dbGetRowsAffected() returns a scalar number (integer or numeric),
the number of rows affected by a data manipulation statement
issued with DBI::dbSendStatement().
The value is available directly after the call
and does not change after calling DBI::dbFetch().
NA_integer_ or NA_numeric_ are allowed if the number of rows affected is not known.
For queries issued with DBI::dbSendQuery(),
zero is returned before
and after the call to dbFetch().
NA values are not allowed.
Other DBIResult generics:
DBIResult-class,
dbBind(),
dbClearResult(),
dbColumnInfo(),
dbFetch(),
dbGetInfo(),
dbGetRowCount(),
dbGetStatement(),
dbHasCompleted(),
dbIsReadOnly(),
dbIsValid(),
dbQuoteLiteral(),
dbQuoteString()
Other command execution generics:
dbBind(),
dbClearResult(),
dbExecute(),
dbSendStatement()